@@ -16,7 +16,7 @@ import sys
 from collections import defaultdict
 from typing import List, TextIO, NamedTuple, Any, Dict, Optional, Sequence
 
-VERSION = '0.3.0'
+VERSION = '0.3.1'
 
 
 class Args(NamedTuple):
@@ -168,14 +168,16 @@ def main() -> None:
         num_shown = 0
 
         for row in reader:
-            vals = {k: v
-                    for k, v in row.items()
-                    if v != ''} if args.dense_view else row
+            # Hack to prevent "None" column
+            row = {f: row[f] for f in reader.fieldnames}
 
-            if grep and not any(grep in x for x in vals.values()):
+            if args.dense_view:
+                row = {k: v for k, v in row.items() if v != ''}
+
+            if grep and not any(grep in x for x in row.values()):
                 continue
 
-            flds = list(vals.keys())
+            flds = list(row.keys())
             if args.field_limit > 0:
                 flds = flds[:args.field_limit + 1]
 
@@ -183,7 +185,7 @@ def main() -> None:
             fmt = '{:' + str(longest + 1) + '}: {}'
             num_shown += 1
             print(f'// ****** Record {num_shown} ****** //')
-            for n, (key, val) in enumerate(vals.items(), start=1):
+            for n, (key, val) in enumerate(row.items(), start=1):
                 show = fmt.format(key, val)
                 if args.show_field_number:
                     print(f'{n:3} {show}')
@@ -232,12 +234,8 @@ def make_cols_unique(names: Optional[Sequence[Any]]) -> List[str]:
         seen: Dict[str, int] = defaultdict(int)
         for name in names:
             num = seen[name]
-            if num == 0:
-                new_names.append(name)
-            else:
-                new_names.append(f'{name}_{num + 1}')
-
             seen[name] += 1
+            new_names.append(f'{name}_{num + 1}' if num > 0 else name)
 
     return new_names
 
